@@ -14,6 +14,13 @@ julia_locate <- function(JULIA_HOME = NULL){
             Sys.getenv("JULIA_HOME")
         }
     }
+    if (is.null(JULIA_HOME)) {
+        depot <- Sys.getenv("JULIA_DEPOT_PATH", unset = julia_default_depot())
+        prefs_file <- file.path(depot, "prefs", "JuliaCall")
+        if (file.exists(prefs_file)) {
+            JULIA_HOME <- readChar(prefs_file, 256)
+        }
+    }
 
     if (is.null(JULIA_HOME)) {
         ## In macOS, the environment variables, e.g., PATH of a GUI is set by launchctl not the SHELL.
@@ -32,9 +39,9 @@ julia_locate <- function(JULIA_HOME = NULL){
                 # if the path is not defined, then try to construct it manually
                 if(appdata_local_path == "") {
                     windows_login_id <- Sys.info()[["login"]]
-                    if(windows_login_id == "unknown") {
-                        stop("The Windows login is 'unknown'. Can not find julia executable")
-                    }
+                    # if(windows_login_id == "unknown") {
+                    #     stop("The Windows login is 'unknown'. Can not find julia executable")
+                    # }
                     appdata_local_path <- file.path("C:/Users/", windows_login_id, "AppData/Local")
                 }
 
@@ -45,26 +52,33 @@ julia_locate <- function(JULIA_HOME = NULL){
                 # which of these folers start with "Julia"
                 x = ld[sort(which(substr(ld,1,5) == "Julia"))]
 
-                if(length(x) == 0) {
-                    stop(sprintf("Can not find the Julia installation in the default installation path '%s'", appdata_local_path))
-                }
-                # TODO if interactive() let the user choose a version of Julia
-                # keep the lastest version of Julia as that is likeley to be the default
-                x = x[length(x)]
+                # if(length(x) == 0) {
+                #     stop(sprintf("Can not find the Julia installation in the default installation path '%s'", appdata_local_path))
+                # }
+                if (length(x) > 0) {
+                    # TODO if interactive() let the user choose a version of Julia
+                    # keep the lastest version of Julia as that is likeley to be the default
+                    x = x[length(x)]
 
-                # filter the ld for folders that starts with Julia
-                julia_bin <- file.path(appdata_local_path, x, "bin/julia.exe")
+                    # filter the ld for folders that starts with Julia
+                    julia_bin <- file.path(appdata_local_path, x, "bin/julia.exe")
+                }
             } else {
                 julia_bin <- "julia"
             }
         }
-        tryCatch(system2(julia_bin, "--startup-file=no -E \"try println(JULIA_HOME) catch e println(Sys.BINDIR) end;\"", stdout = TRUE)[1],
+        tryCatch({r <- system2(julia_bin, "--startup-file=no -E \"1;\"", stdout = TRUE);
+                  r <- system2(julia_bin, "--startup-file=no -E \"try println(JULIA_HOME) catch e println(Sys.BINDIR) end;\"", stdout = TRUE);
+                  r[length(r)-1]},
                  warning = function(war) {},
                  error = function(err) NULL)
     }
     else {
-        tryCatch(system2(file.path(JULIA_HOME, "julia"),
-                         "--startup-file=no -E \"try println(JULIA_HOME) catch e println(Sys.BINDIR) end;\"", stdout = TRUE)[1],
+        tryCatch({r <- system2(file.path(JULIA_HOME, "julia"),
+                               "--startup-file=no -E \"1;\"", stdout = TRUE);
+                  r <- system2(file.path(JULIA_HOME, "julia"),
+                         "--startup-file=no -E \"try println(JULIA_HOME) catch e println(Sys.BINDIR) end;\"", stdout = TRUE);
+                  r[length(r)-1]},
                  warning = function(war) {},
                  error = function(err) NULL)
     }
@@ -78,6 +92,7 @@ julia_locate <- function(JULIA_HOME = NULL){
 julia_line <- function(command, ...){
     command <- c("--startup-file=no", command)
     system2(file.path(.julia$bin_dir, "julia"), shQuote(command), ...)
+    # r[length(r)]
 }
 
 newer <- function(x, y){
