@@ -24,7 +24,8 @@
 #'     If a new version of R is used, then this parameter needs to be set to TRUE.
 #' @param sysimage_path path to the precompiled custom sys image.
 #'     Path can be either an absolute path or relative to the current directory.
-#'
+#' @param version the version of Julia to install. Defaults to "latest", which is the latest
+#'     released version of Julia. You can use "1.10" for example for Julia v1.10.
 #' @return The julia interface, which is an environment with the necessary methods
 #'   like command, source and things like that to communicate with julia.
 #'
@@ -38,7 +39,8 @@
 julia_setup <- function(JULIA_HOME = NULL, verbose = TRUE,
                         installJulia = FALSE,
                         install = TRUE, force = FALSE, useRCall = TRUE,
-                        rebuild = FALSE, sysimage_path = NULL) {
+                        rebuild = FALSE, sysimage_path = NULL,
+                        version = "latest") {
     ## libR <- paste0(R.home(), '/lib')
     ## system(paste0('export LD_LIBRARY_PATH=', libR, ':$LD_LIBRARY_PATH'))
 
@@ -55,7 +57,7 @@ julia_setup <- function(JULIA_HOME = NULL, verbose = TRUE,
 
     if (is.null(JULIA_HOME)) {
         if (isTRUE(installJulia)) {
-            install_julia()
+            install_julia(version)
             JULIA_HOME <- julia_locate(JULIA_HOME)
             if (is.null(JULIA_HOME))
                 stop("Julia is not found and automatic installation failed.")
