@@ -4,7 +4,7 @@ test_that("test juliacall in rmd", {
     skip_on_cran()
     skip_on_appveyor()
 
-    tmp <- tempfile()
+    tmp <- tempfile(fileext = ".md")
     rmarkdown::render(test_path("Rmd_test.Rmd"), output_file = tmp)
     expect_true(file.exists(tmp))
     r <- paste(readLines(tmp), collapse = "\n")
